/*
 * System Interface Library for games
 * Copyright (c) 2007-2017 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * include/SIL/configs/windows.h: Configuration header for Windows.
 */

#ifndef SIL_CONFIGS_WINDOWS_H
#define SIL_CONFIGS_WINDOWS_H

/*************************************************************************/
/*************************************************************************/

#define SIL_PLATFORM_WINDOWS
#define SIL_SYSTEM_COMMON_HEADER  "sysdep/windows/common.h"

/* Windows only runs on little-endian platforms. */
#define IS_LITTLE_ENDIAN

#ifdef _MSC_VER

# warn Compiling with Visual Studio has not been tested in many years and is probably broken.

# define HAVE__STRICMP
# define STRNICMP_SIZE_T  size_t

/* Disable various unneeded warnings. */
# pragma warning(disable:4244)  // Loss of numeric precision (integer size)
# pragma warning(disable:4258)  // Not using for-scope extension (why warn...?)
# pragma warning(disable:4267)  // Loss of numeric precision (size_t -> int)
# pragma warning(disable:4305)  // Loss of numeric precision (generic)
# pragma warning(disable:4800)  // Conversion of non-bool to bool
# pragma warning(disable:4805)  // Comparison of non-bool and bool

# if !defined(__cplusplus)
#  define inline  __inline
# endif

# undef _DEBUG  // Use in MS headers conflicts with some of our code.

#else  // !_MSC_VER

# if defined(__i386__)
#  define SIL_ARCH_X86
#  define SIL_ARCH_X86_32
# elif defined(__amd64__)
#  define SIL_ARCH_X86
#  define SIL_ARCH_X86_64
# elif defined(__arm__)
#  define SIL_ARCH_ARM
#  define SIL_ARCH_ARM_32
# else
#  warning Unknown CPU architecture!
# endif

/* MinGW's libc has strcasecmp() but not in <strings.h>, so we use our own
 * instead.  At least some versions of <string.h> declare str[n]icmp(),
 * though, so we need to use the correct type. */
//# define HAVE_STRCASECMP
# define STRNICMP_SIZE_T  size_t

#endif

/*************************************************************************/
/*************************************************************************/

#endif  // SIL_CONFIGS_WINDOWS_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
